"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    skill_group_name: str,
    description: str = None,
    client_request_token: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a skill group with a specified name and description.

    Args:
        skill_group_name(str): The name for the skill group.
        description(str, optional): The description for the skill group. Defaults to None.
        client_request_token(str, optional): A unique, user-specified identifier for this request that ensures idempotency. . Defaults to None.
        tags(List, optional): The tags for the skill group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.skill.group.init.create(
                ctx, skill_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.skill.group.init.create skill_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="create_skill_group",
        op_kwargs={
            "SkillGroupName": skill_group_name,
            "Description": description,
            "ClientRequestToken": client_request_token,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, skill_group_arn: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a skill group by skill group ARN.

    Args:
        skill_group_arn(str, optional): The ARN of the skill group to delete. Required. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.skill.group.init.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.skill.group.init.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="delete_skill_group",
        op_kwargs={"SkillGroupArn": skill_group_arn},
    )


async def get(hub, ctx, skill_group_arn: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets skill group details by skill group ARN.

    Args:
        skill_group_arn(str, optional): The ARN of the skill group for which to get details. Required. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.skill.group.init.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.skill.group.init.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="get_skill_group",
        op_kwargs={"SkillGroupArn": skill_group_arn},
    )


async def search(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    filters: List = None,
    sort_criteria: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Searches skill groups and lists the ones that meet a set of filter and sort criteria.

    Args:
        next_token(str, optional): An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token, up to the value specified by MaxResults. Required. Defaults to None.
        max_results(int, optional): The maximum number of results to include in the response. If more results exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved. . Defaults to None.
        filters(List, optional): The filters to use to list a specified set of skill groups. The supported filter key is SkillGroupName. . Defaults to None.
        sort_criteria(List, optional): The sort order to use in listing the specified set of skill groups. The supported sort key is SkillGroupName. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.skill.group.init.search(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.skill.group.init.search
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="search_skill_groups",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "Filters": filters,
            "SortCriteria": sort_criteria,
        },
    )


async def update(
    hub,
    ctx,
    skill_group_arn: str = None,
    skill_group_name: str = None,
    description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates skill group details by skill group ARN.

    Args:
        skill_group_arn(str, optional): The ARN of the skill group to update. . Defaults to None.
        skill_group_name(str, optional): The updated name for the skill group. Defaults to None.
        description(str, optional): The updated description for the skill group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.skill.group.init.update(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.skill.group.init.update
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="update_skill_group",
        op_kwargs={
            "SkillGroupArn": skill_group_arn,
            "SkillGroupName": skill_group_name,
            "Description": description,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub, ctx, attribute: str, image_id: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified attribute of the specified AMI. You can specify only one attribute at a time.

    Args:
        attribute(str): The AMI attribute.  Note: The blockDeviceMapping attribute is deprecated. Using this attribute returns the Client.AuthFailure error. To get information about the block device mappings for an AMI, use the DescribeImages action.
        image_id(str): The ID of the AMI.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.image.attribute.describe(
                ctx, attribute=value, image_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.image.attribute.describe attribute=value, image_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_image_attribute",
        op_kwargs={"Attribute": attribute, "ImageId": image_id, "DryRun": dry_run},
    )


async def modify(
    hub,
    ctx,
    image_id: str,
    attribute: str = None,
    description: Dict = None,
    launch_permission: Dict = None,
    operation_type: str = None,
    product_codes: List = None,
    user_groups: List = None,
    user_ids: List = None,
    value: str = None,
    dry_run: bool = None,
) -> None:
    r"""
    **Autogenerated function**

    Modifies the specified attribute of the specified AMI. You can specify only one attribute at a time. You can use the Attribute parameter to specify the attribute or one of the following parameters: Description, LaunchPermission, or ProductCode. AWS Marketplace product codes cannot be modified. Images with an AWS Marketplace product code cannot be made public. To enable the SriovNetSupport enhanced networking attribute of an image, enable SriovNetSupport on an instance and create an AMI from the instance.

    Args:
        attribute(str, optional): The name of the attribute to modify. The valid values are description, launchPermission, and productCodes. Defaults to None.
        description(Dict, optional): A new description for the AMI. Defaults to None.
        image_id(str): The ID of the AMI.
        launch_permission(Dict, optional): A new launch permission for the AMI. Defaults to None.
        operation_type(str, optional): The operation type. This parameter can be used only when the Attribute parameter is launchPermission. Defaults to None.
        product_codes(List, optional): The DevPay product codes. After you add a product code to an AMI, it can't be removed. Defaults to None.
        user_groups(List, optional): The user groups. This parameter can be used only when the Attribute parameter is launchPermission. Defaults to None.
        user_ids(List, optional): The AWS account IDs. This parameter can be used only when the Attribute parameter is launchPermission. Defaults to None.
        value(str, optional): The value of the attribute being modified. This parameter can be used only when the Attribute parameter is description or productCodes. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.image.attribute.modify(ctx, image_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.image.attribute.modify image_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_image_attribute",
        op_kwargs={
            "Attribute": attribute,
            "Description": description,
            "ImageId": image_id,
            "LaunchPermission": launch_permission,
            "OperationType": operation_type,
            "ProductCodes": product_codes,
            "UserGroups": user_groups,
            "UserIds": user_ids,
            "Value": value,
            "DryRun": dry_run,
        },
    )


async def reset(hub, ctx, attribute: str, image_id: str, dry_run: bool = None) -> None:
    r"""
    **Autogenerated function**

    Resets an attribute of an AMI to its default value.  The productCodes attribute can't be reset.

    Args:
        attribute(str): The attribute to reset (currently you can only reset the launch permission attribute).
        image_id(str): The ID of the AMI.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.image.attribute.reset(ctx, attribute=value, image_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.image.attribute.reset attribute=value, image_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="reset_image_attribute",
        op_kwargs={"Attribute": attribute, "ImageId": image_id, "DryRun": dry_run},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, job_id: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the text detection results of a Amazon Rekognition Video analysis started by StartTextDetection. Text detection with Amazon Rekognition Video is an asynchronous operation. You start text detection by calling StartTextDetection which returns a job identifier (JobId) When the text detection operation finishes, Amazon Rekognition publishes a completion status to the Amazon Simple Notification Service topic registered in the initial call to StartTextDetection. To get the results of the text detection operation, first check that the status value published to the Amazon SNS topic is SUCCEEDED. if so, call GetTextDetection and pass the job identifier (JobId) from the initial call of StartLabelDetection.  GetTextDetection returns an array of detected text (TextDetections) sorted by the time the text was detected, up to 50 words per frame of video. Each element of the array includes the detected text, the precentage confidence in the acuracy of the detected text, the time the text was detected, bounding box information for where the text was located, and unique identifiers for words and their lines. Use MaxResults parameter to limit the number of text detections returned. If there are more results than specified in MaxResults, the value of NextToken in the operation response contains a pagination token for getting the next set of results. To get the next page of results, call GetTextDetection and populate the NextToken request parameter with the token value returned from the previous call to GetTextDetection.

    Args:
        job_id(str): Job identifier for the text detection operation for which you want results returned. You get the job identifer from an initial call to StartTextDetection.
        max_results(int, optional): Maximum number of results to return per paginated call. The largest value you can specify is 1000. Defaults to None.
        next_token(str, optional): If the previous response was incomplete (because there are more labels to retrieve), Amazon Rekognition Video returns a pagination token in the response. You can use this pagination token to retrieve the next set of text. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.text.detection.get(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.text.detection.get job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="get_text_detection",
        op_kwargs={"JobId": job_id, "MaxResults": max_results, "NextToken": next_token},
    )


async def start(
    hub,
    ctx,
    video: Dict,
    client_request_token: str = None,
    notification_channel: Dict = None,
    job_tag: str = None,
    filters: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts asynchronous detection of text in a stored video. Amazon Rekognition Video can detect text in a video stored in an Amazon S3 bucket. Use Video to specify the bucket name and the filename of the video. StartTextDetection returns a job identifier (JobId) which you use to get the results of the operation. When text detection is finished, Amazon Rekognition Video publishes a completion status to the Amazon Simple Notification Service topic that you specify in NotificationChannel. To get the results of the text detection operation, first check that the status value published to the Amazon SNS topic is SUCCEEDED. if so, call GetTextDetection and pass the job identifier (JobId) from the initial call to StartTextDetection.

    Args:
        video(Dict): Video file stored in an Amazon S3 bucket. Amazon Rekognition video start operations such as StartLabelDetection use Video to specify a video for analysis. The supported file formats are .mp4, .mov and .avi.
        client_request_token(str, optional): Idempotent token used to identify the start request. If you use the same token with multiple StartTextDetection requests, the same JobId is returned. Use ClientRequestToken to prevent the same job from being accidentaly started more than once. Defaults to None.
        notification_channel(Dict, optional): The Amazon Simple Notification Service topic to which Amazon Rekognition publishes the completion status of a video analysis operation. For more information, see api-video. Defaults to None.
        job_tag(str, optional): An identifier returned in the completion status published by your Amazon Simple Notification Service topic. For example, you can use JobTag to group related jobs and identify them in the completion notification. Defaults to None.
        filters(Dict, optional): Optional parameters that let you set criteria the text must meet to be included in your response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.text.detection.start(ctx, video=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.text.detection.start video=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="start_text_detection",
        op_kwargs={
            "Video": video,
            "ClientRequestToken": client_request_token,
            "NotificationChannel": notification_channel,
            "JobTag": job_tag,
            "Filters": filters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    account_id: str,
    job_statuses: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists current S3 Batch Operations jobs and jobs that have ended within the last 30 days for the account making the request. For more information, see S3 Batch Operations in the Amazon S3 User Guide. Related actions include:     CreateJob     DescribeJob     UpdateJobPriority     UpdateJobStatus

    Args:
        account_id(str): The account ID associated with the S3 Batch Operations job.
        job_statuses(List, optional): The List Jobs request returns jobs that match the statuses listed in this element. Defaults to None.
        next_token(str, optional): A pagination token to request the next page of results. Use the token that Amazon S3 returned in the NextToken element of the ListJobsResult from the previous List Jobs request. Defaults to None.
        max_results(int, optional): The maximum number of jobs that Amazon S3 will include in the List Jobs response. If there are more jobs than this number, the response will include a pagination token in the NextToken field to enable you to retrieve the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.jobs.list(ctx, account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.jobs.list account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="list_jobs",
        op_kwargs={
            "AccountId": account_id,
            "JobStatuses": job_statuses,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def tag(hub, ctx, arn: str, tags: List) -> None:
    r"""
    **Autogenerated function**

    Attaches a key-value pair to a resource, as identified by its Amazon Resource Name (ARN). Resources are users, servers, roles, and other entities. There is no response returned from this call.

    Args:
        arn(str): An Amazon Resource Name (ARN) for a specific Amazon Web Services resource, such as a server, user, or role.
        tags(List): Key-value pairs assigned to ARNs that you can use to group and search for resources by type. You can attach this metadata to user accounts for any purpose.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transfer.resource.tag(ctx, arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transfer.resource.tag arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transfer",
        operation="tag_resource",
        op_kwargs={"Arn": arn, "Tags": tags},
    )


async def untag(hub, ctx, arn: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Detaches a key-value pair from a resource, as identified by its Amazon Resource Name (ARN). Resources are users, servers, roles, and other entities. No response is returned from this call.

    Args:
        arn(str): The value of the resource that will have the tag removed. An Amazon Resource Name (ARN) is an identifier for a specific Amazon Web Services resource, such as a server, user, or role.
        tag_keys(List): TagKeys are key-value pairs assigned to ARNs that can be used to group and search for resources by type. This metadata can be attached to resources for any purpose.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transfer.resource.untag(ctx, arn=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transfer.resource.untag arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transfer",
        operation="untag_resource",
        op_kwargs={"Arn": arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Permanently deletes the LoggingConfiguration from the specified web ACL.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the web ACL from which you want to delete the LoggingConfiguration.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf.logging_configuration.delete(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf.logging_configuration.delete resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf",
        operation="delete_logging_configuration",
        op_kwargs={"ResourceArn": resource_arn},
    )


async def get(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns the LoggingConfiguration for the specified web ACL.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the web ACL for which you want to get the LoggingConfiguration.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf.logging_configuration.get(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf.logging_configuration.get resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf",
        operation="get_logging_configuration",
        op_kwargs={"ResourceArn": resource_arn},
    )


async def list_all(hub, ctx, next_marker: str = None, limit: int = None) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns an array of LoggingConfiguration objects.

    Args:
        next_marker(str, optional): If you specify a value for Limit and you have more LoggingConfigurations than the value of Limit, AWS WAF returns a NextMarker value in the response that allows you to list another group of LoggingConfigurations. For the second and subsequent ListLoggingConfigurations requests, specify the value of NextMarker from the previous response to get information about another batch of ListLoggingConfigurations. Defaults to None.
        limit(int, optional): Specifies the number of LoggingConfigurations that you want AWS WAF to return for this request. If you have more LoggingConfigurations than the number that you specify for Limit, the response includes a NextMarker value that you can use to get another batch of LoggingConfigurations. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf.logging_configuration.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf.logging_configuration.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf",
        operation="list_logging_configurations",
        op_kwargs={"NextMarker": next_marker, "Limit": limit},
    )


async def put(hub, ctx, logging_configuration: Dict) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Associates a LoggingConfiguration with a specified web ACL. You can access information about all traffic that AWS WAF inspects using the following steps:   Create an Amazon Kinesis Data Firehose.  Create the data firehose with a PUT source and in the region that you are operating. However, if you are capturing logs for Amazon CloudFront, always create the firehose in US East (N. Virginia).   Do not create the data firehose using a Kinesis stream as your source.    Associate that firehose to your web ACL using a PutLoggingConfiguration request.   When you successfully enable logging using a PutLoggingConfiguration request, AWS WAF will create a service linked role with the necessary permissions to write logs to the Amazon Kinesis Data Firehose. For more information, see Logging Web ACL Traffic Information in the AWS WAF Developer Guide.

    Args:
        logging_configuration(Dict): The Amazon Kinesis Data Firehose that contains the inspected traffic information, the redacted fields details, and the Amazon Resource Name (ARN) of the web ACL to monitor.  When specifying Type in RedactedFields, you must use one of the following values: URI, QUERY_STRING, HEADER, or METHOD. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf.logging_configuration.put(ctx, logging_configuration=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf.logging_configuration.put logging_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf",
        operation="put_logging_configuration",
        op_kwargs={"LoggingConfiguration": logging_configuration},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(
    hub, ctx, tape_arn: str, bypass_governance_retention: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified virtual tape from the virtual tape shelf (VTS). This operation is only supported in the tape gateway type.

    Args:
        tape_arn(str): The Amazon Resource Name (ARN) of the virtual tape to delete from the virtual tape shelf (VTS).
        bypass_governance_retention(bool, optional): Set to TRUE to delete an archived tape that belongs to a custom pool with tape retention lock. Only archived tapes with tape retention lock set to governance can be deleted. Archived tapes with tape retention lock set to compliance can't be deleted. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.tape.archive.delete(ctx, tape_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.tape.archive.delete tape_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="delete_tape_archive",
        op_kwargs={
            "TapeARN": tape_arn,
            "BypassGovernanceRetention": bypass_governance_retention,
        },
    )


async def describe_all(
    hub, ctx, tape_ar_ns: List = None, marker: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a description of specified virtual tapes in the virtual tape shelf (VTS). This operation is only supported in the tape gateway type. If a specific TapeARN is not specified, Storage Gateway returns a description of all virtual tapes found in the VTS associated with your account.

    Args:
        tape_ar_ns(List, optional): Specifies one or more unique Amazon Resource Names (ARNs) that represent the virtual tapes you want to describe. Defaults to None.
        marker(str, optional): An opaque string that indicates the position at which to begin describing virtual tapes. Defaults to None.
        limit(int, optional): Specifies that the number of virtual tapes described be limited to the specified number. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.tape.archive.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.tape.archive.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="describe_tape_archives",
        op_kwargs={"TapeARNs": tape_ar_ns, "Marker": marker, "Limit": limit},
    )


async def retrieve(hub, ctx, tape_arn: str, gateway_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves an archived virtual tape from the virtual tape shelf (VTS) to a tape gateway. Virtual tapes archived in the VTS are not associated with any gateway. However after a tape is retrieved, it is associated with a gateway, even though it is also listed in the VTS, that is, archive. This operation is only supported in the tape gateway type. Once a tape is successfully retrieved to a gateway, it cannot be retrieved again to another gateway. You must archive the tape again before you can retrieve it to another gateway. This operation is only supported in the tape gateway type.

    Args:
        tape_arn(str): The Amazon Resource Name (ARN) of the virtual tape you want to retrieve from the virtual tape shelf (VTS).
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway you want to retrieve the virtual tape to. Use the ListGateways operation to return a list of gateways for your account and Region. You retrieve archived virtual tapes to only one gateway and the gateway must be a tape gateway.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.tape.archive.retrieve(
                ctx, tape_arn=value, gateway_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.tape.archive.retrieve tape_arn=value, gateway_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="retrieve_tape_archive",
        op_kwargs={"TapeARN": tape_arn, "GatewayARN": gateway_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, role_name: str, account_id: str, access_token: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the STS short-term credentials for a given role name that is assigned to the user.

    Args:
        role_name(str): The friendly name of the role that is assigned to the user.
        account_id(str): The identifier for the AWS account that is assigned to the user.
        access_token(str): The token issued by the CreateToken API call. For more information, see CreateToken in the AWS SSO OIDC API Reference Guide.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso.role_credential.get_all(
                ctx, role_name=value, account_id=value, access_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso.role_credential.get_all role_name=value, account_id=value, access_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso",
        operation="get_role_credentials",
        op_kwargs={
            "roleName": role_name,
            "accountId": account_id,
            "accessToken": access_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    type_: str,
    string_values: List,
    client_request_token: str,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create a dimension that you can use to limit the scope of a metric used in a security profile for AWS IoT Device Defender. For example, using a TOPIC_FILTER dimension, you can narrow down the scope of the metric only to MQTT topics whose name match the pattern specified in the dimension.

    Args:
        name(str): A unique identifier for the dimension. Choose something that describes the type and value to make it easy to remember what it does.
        type_(str): Specifies the type of dimension. Supported types: TOPIC_FILTER. .
        string_values(List): Specifies the value or list of values for the dimension. For TOPIC_FILTER dimensions, this is a pattern used to match the MQTT topic (for example, "admin/#").
        tags(List, optional): Metadata that can be used to manage the dimension. Defaults to None.
        client_request_token(str): Each dimension must have a unique client request token. If you try to create a new dimension with the same token as a dimension that already exists, an exception occurs. If you omit this value, AWS SDKs will automatically generate a unique client request.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.dimension.create(
                ctx, name=value, type_=value, string_values=value, client_request_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.dimension.create name=value, type_=value, string_values=value, client_request_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="create_dimension",
        op_kwargs={
            "name": name,
            "type": type_,
            "stringValues": string_values,
            "tags": tags,
            "clientRequestToken": client_request_token,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes the specified dimension from your AWS account.

    Args:
        name(str): The unique identifier for the dimension that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.dimension.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.dimension.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="iot", operation="delete_dimension", op_kwargs={"name": name}
    )


async def describe(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides details about a dimension that is defined in your AWS account.

    Args:
        name(str): The unique identifier for the dimension.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.dimension.describe(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.dimension.describe name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="describe_dimension",
        op_kwargs={"name": name},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    List the set of dimensions that are defined for your AWS account.

    Args:
        next_token(str, optional): The token for the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to retrieve at one time. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.dimension.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.dimension.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_dimensions",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )


async def update(hub, ctx, name: str, string_values: List) -> Dict:
    r"""
    **Autogenerated function**

    Updates the definition for a dimension. You cannot change the type of a dimension after it is created (you can delete it and recreate it).

    Args:
        name(str): A unique identifier for the dimension. Choose something that describes the type and value to make it easy to remember what it does.
        string_values(List): Specifies the value or list of values for the dimension. For TOPIC_FILTER dimensions, this is a pattern used to match the MQTT topic (for example, "admin/#").

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.dimension.update(ctx, name=value, string_values=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.dimension.update name=value, string_values=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="update_dimension",
        op_kwargs={"name": name, "stringValues": string_values},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    application_id: str,
    kpi_name: str,
    end_time: str = None,
    next_token: str = None,
    page_size: str = None,
    start_time: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves (queries) pre-aggregated data for a standard metric that applies to an application.

    Args:
        application_id(str): The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.
        end_time(str, optional): The last date and time to retrieve data for, as part of an inclusive date range that filters the query results. This value should be in extended ISO 8601 format and use Coordinated Universal Time (UTC), for example: 2019-07-26T20:00:00Z for 8:00 PM UTC July 26, 2019. Defaults to None.
        kpi_name(str): The name of the metric, also referred to as a key performance indicator (KPI), to retrieve data for. This value describes the associated metric and consists of two or more terms, which are comprised of lowercase alphanumeric characters, separated by a hyphen. Examples are email-open-rate and successful-delivery-rate. For a list of valid values, see the Amazon Pinpoint Developer Guide.
        next_token(str, optional): The  string that specifies which page of results to return in a paginated response. This parameter is not supported for application, campaign, and journey metrics. Defaults to None.
        page_size(str, optional): The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics. Defaults to None.
        start_time(str, optional): The first date and time to retrieve data for, as part of an inclusive date range that filters the query results. This value should be in extended ISO 8601 format and use Coordinated Universal Time (UTC), for example: 2019-07-19T20:00:00Z for 8:00 PM UTC July 19, 2019. This value should also be fewer than 90 days from the current day. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.application.date_range_kpi.get(
                ctx, application_id=value, kpi_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.application.date_range_kpi.get application_id=value, kpi_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="get_application_date_range_kpi",
        op_kwargs={
            "ApplicationId": application_id,
            "EndTime": end_time,
            "KpiName": kpi_name,
            "NextToken": next_token,
            "PageSize": page_size,
            "StartTime": start_time,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: Dict) -> Dict:
    r"""
    **Autogenerated function**

     Adds one or more key-value tags to an Amazon Rekognition collection, stream processor, or Custom Labels model. For more information, see Tagging AWS Resources.  This operation requires permissions to perform the rekognition:TagResource action.

    Args:
        resource_arn(str):  Amazon Resource Name (ARN) of the model, collection, or stream processor that you want to assign the tags to. .
        tags(Dict):  The key-value tags to assign to the resource. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="tag_resource",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

     Removes one or more tags from an Amazon Rekognition collection, stream processor, or Custom Labels model.  This operation requires permissions to perform the rekognition:UntagResource action.

    Args:
        resource_arn(str):  Amazon Resource Name (ARN) of the model, collection, or stream processor that you want to remove the tags from. .
        tag_keys(List):  A list of the tags that you want to remove. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.resource.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="untag_resource",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

     Assigns a tag to a GameLift resource. AWS resource tags provide an additional management tool set. You can use tags to organize resources, create IAM permissions policies to manage access to groups of resources, customize AWS cost breakdowns, etc. This operation handles the permissions necessary to manage tags for the following GameLift resource types:   Build   Script   Fleet   Alias   GameSessionQueue   MatchmakingConfiguration   MatchmakingRuleSet   To add a tag to a resource, specify the unique ARN value for the resource and provide a tag list containing one or more tags. The operation succeeds even if the list includes tags that are already assigned to the specified resource.   Learn more   Tagging AWS Resources in the AWS General Reference    AWS Tagging Strategies   Related actions   TagResource | UntagResource | ListTagsForResource | All APIs by task

    Args:
        resource_arn(str):  The Amazon Resource Name (ARN) that is assigned to and uniquely identifies the GameLift resource that you want to assign tags to. GameLift resource ARNs are included in the data object for the resource, which can be retrieved by calling a List or Describe operation for the resource type. .
        tags(List): A list of one or more tags to assign to the specified GameLift resource. Tags are developer-defined and structured as key-value pairs. The maximum tag limit may be lower than stated. See  Tagging AWS Resources for actual tagging limits.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="tag_resource",
        op_kwargs={"ResourceARN": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes a tag that is assigned to a GameLift resource. Resource tags are used to organize AWS resources for a range of purposes. This operation handles the permissions necessary to manage tags for the following GameLift resource types:   Build   Script   Fleet   Alias   GameSessionQueue   MatchmakingConfiguration   MatchmakingRuleSet   To remove a tag from a resource, specify the unique ARN value for the resource and provide a string list containing one or more tags to be removed. This operation succeeds even if the list includes tags that are not currently assigned to the specified resource.  Learn more   Tagging AWS Resources in the AWS General Reference    AWS Tagging Strategies   Related actions   TagResource | UntagResource | ListTagsForResource | All APIs by task

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) that is assigned to and uniquely identifies the GameLift resource that you want to remove tags from. GameLift resource ARNs are included in the data object for the resource, which can be retrieved by calling a List or Describe operation for the resource type. .
        tag_keys(List): A list of one or more tag keys to remove from the specified GameLift resource. An AWS resource can have only one tag with a specific tag key, so specifying the tag key identifies which tag to remove. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.resource.untag(ctx, resource_arn=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="untag_resource",
        op_kwargs={"ResourceARN": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def add(hub, ctx, flow_arn: str, sources: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds Sources to flow

    Args:
        flow_arn(str): The flow that you want to mutate.
        sources(List): A list of sources that you want to add.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconnect.flow.source.add(ctx, flow_arn=value, sources=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconnect.flow.source.add flow_arn=value, sources=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconnect",
        operation="add_flow_sources",
        op_kwargs={"FlowArn": flow_arn, "Sources": sources},
    )


async def remove(hub, ctx, flow_arn: str, source_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes a source from an existing flow. This request can be made only if there is more than one source on the flow.

    Args:
        flow_arn(str): The flow that you want to remove a source from.
        source_arn(str): The ARN of the source that you want to remove.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconnect.flow.source.remove(
                ctx, flow_arn=value, source_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconnect.flow.source.remove flow_arn=value, source_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconnect",
        operation="remove_flow_source",
        op_kwargs={"FlowArn": flow_arn, "SourceArn": source_arn},
    )


async def update(
    hub,
    ctx,
    flow_arn: str,
    source_arn: str,
    decryption: Dict = None,
    description: str = None,
    entitlement_arn: str = None,
    ingest_port: int = None,
    max_bitrate: int = None,
    max_latency: int = None,
    max_sync_buffer: int = None,
    media_stream_source_configurations: List = None,
    min_latency: int = None,
    protocol: str = None,
    stream_id: str = None,
    vpc_interface_name: str = None,
    whitelist_cidr: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the source of a flow.

    Args:
        decryption(Dict, optional): The type of encryption used on the content ingested from this source. Defaults to None.
        description(str, optional): A description for the source. This value is not used or seen outside of the current AWS Elemental MediaConnect account. Defaults to None.
        entitlement_arn(str, optional): The ARN of the entitlement that allows you to subscribe to this flow. The entitlement is set by the flow originator, and the ARN is generated as part of the originator's flow. Defaults to None.
        flow_arn(str): The flow that is associated with the source that you want to update.
        ingest_port(int, optional): The port that the flow will be listening on for incoming content. Defaults to None.
        max_bitrate(int, optional): The smoothing max bitrate for RIST, RTP, and RTP-FEC streams. Defaults to None.
        max_latency(int, optional): The maximum latency in milliseconds. This parameter applies only to RIST-based and Zixi-based streams. Defaults to None.
        max_sync_buffer(int, optional): The size of the buffer (in milliseconds) to use to sync incoming source data. Defaults to None.
        media_stream_source_configurations(List, optional): The media streams that are associated with the source, and the parameters for those associations. Defaults to None.
        min_latency(int, optional): The minimum latency in milliseconds for SRT-based streams. In streams that use the SRT protocol, this value that you set on your MediaConnect source or output represents the minimal potential latency of that connection. The latency of the stream is set to the highest number between the sender’s minimum latency and the receiver’s minimum latency. Defaults to None.
        protocol(str, optional): The protocol that is used by the source. Defaults to None.
        source_arn(str): The ARN of the source that you want to update.
        stream_id(str, optional): The stream ID that you want to use for this transport. This parameter applies only to Zixi-based streams. Defaults to None.
        vpc_interface_name(str, optional): The name of the VPC interface to use for this source. Defaults to None.
        whitelist_cidr(str, optional): The range of IP addresses that should be allowed to contribute content to your source. These IP addresses should be in the form of a Classless Inter-Domain Routing (CIDR) block; for example, 10.0.0.0/16. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconnect.flow.source.update(
                ctx, flow_arn=value, source_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconnect.flow.source.update flow_arn=value, source_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconnect",
        operation="update_flow_source",
        op_kwargs={
            "Decryption": decryption,
            "Description": description,
            "EntitlementArn": entitlement_arn,
            "FlowArn": flow_arn,
            "IngestPort": ingest_port,
            "MaxBitrate": max_bitrate,
            "MaxLatency": max_latency,
            "MaxSyncBuffer": max_sync_buffer,
            "MediaStreamSourceConfigurations": media_stream_source_configurations,
            "MinLatency": min_latency,
            "Protocol": protocol,
            "SourceArn": source_arn,
            "StreamId": stream_id,
            "VpcInterfaceName": vpc_interface_name,
            "WhitelistCidr": whitelist_cidr,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    listener_arn: str,
    endpoint_group_region: str,
    idempotency_token: str,
    endpoint_configurations: List = None,
    traffic_dial_percentage: float = None,
    health_check_port: int = None,
    health_check_protocol: str = None,
    health_check_path: str = None,
    health_check_interval_seconds: int = None,
    threshold_count: int = None,
    port_overrides: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create an endpoint group for the specified listener. An endpoint group is a collection of endpoints in one AWS Region. A resource must be valid and active when you add it as an endpoint.

    Args:
        listener_arn(str): The Amazon Resource Name (ARN) of the listener.
        endpoint_group_region(str): The AWS Region where the endpoint group is located. A listener can have only one endpoint group in a specific Region.
        endpoint_configurations(List, optional): The list of endpoint objects. Defaults to None.
        traffic_dial_percentage(float, optional): The percentage of traffic to send to an AWS Region. Additional traffic is distributed to other endpoint groups for this listener.  Use this action to increase (dial up) or decrease (dial down) traffic to a specific Region. The percentage is applied to the traffic that would otherwise have been routed to the Region based on optimal routing. The default value is 100. Defaults to None.
        health_check_port(int, optional): The port that AWS Global Accelerator uses to check the health of endpoints that are part of this endpoint group. The default port is the listener port that this endpoint group is associated with. If listener port is a list of ports, Global Accelerator uses the first port in the list. Defaults to None.
        health_check_protocol(str, optional): The protocol that AWS Global Accelerator uses to check the health of endpoints that are part of this endpoint group. The default value is TCP. Defaults to None.
        health_check_path(str, optional): If the protocol is HTTP/S, then this specifies the path that is the destination for health check targets. The default value is slash (/). Defaults to None.
        health_check_interval_seconds(int, optional): The time—10 seconds or 30 seconds—between each health check for an endpoint. The default value is 30. Defaults to None.
        threshold_count(int, optional): The number of consecutive health checks required to set the state of a healthy endpoint to unhealthy, or to set an unhealthy endpoint to healthy. The default value is 3. Defaults to None.
        idempotency_token(str): A unique, case-sensitive identifier that you provide to ensure the idempotency—that is, the uniqueness—of the request.
        port_overrides(List, optional): Override specific listener ports used to route traffic to endpoints that are part of this endpoint group. For example, you can create a port override in which the listener receives user traffic on ports 80 and 443, but your accelerator routes that traffic to ports 1080 and 1443, respectively, on the endpoints. For more information, see  Port overrides in the AWS Global Accelerator Developer Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.endpoint_group.create(
                ctx, listener_arn=value, endpoint_group_region=value, idempotency_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.endpoint_group.create listener_arn=value, endpoint_group_region=value, idempotency_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="create_endpoint_group",
        op_kwargs={
            "ListenerArn": listener_arn,
            "EndpointGroupRegion": endpoint_group_region,
            "EndpointConfigurations": endpoint_configurations,
            "TrafficDialPercentage": traffic_dial_percentage,
            "HealthCheckPort": health_check_port,
            "HealthCheckProtocol": health_check_protocol,
            "HealthCheckPath": health_check_path,
            "HealthCheckIntervalSeconds": health_check_interval_seconds,
            "ThresholdCount": threshold_count,
            "IdempotencyToken": idempotency_token,
            "PortOverrides": port_overrides,
        },
    )


async def delete(hub, ctx, endpoint_group_arn: str) -> None:
    r"""
    **Autogenerated function**

    Delete an endpoint group from a listener.

    Args:
        endpoint_group_arn(str): The Amazon Resource Name (ARN) of the endpoint group to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.endpoint_group.delete(
                ctx, endpoint_group_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.endpoint_group.delete endpoint_group_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="delete_endpoint_group",
        op_kwargs={"EndpointGroupArn": endpoint_group_arn},
    )


async def describe(hub, ctx, endpoint_group_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describe an endpoint group.

    Args:
        endpoint_group_arn(str): The Amazon Resource Name (ARN) of the endpoint group to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.endpoint_group.describe(
                ctx, endpoint_group_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.endpoint_group.describe endpoint_group_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="describe_endpoint_group",
        op_kwargs={"EndpointGroupArn": endpoint_group_arn},
    )


async def list_all(
    hub, ctx, listener_arn: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    List the endpoint groups that are associated with a listener.

    Args:
        listener_arn(str): The Amazon Resource Name (ARN) of the listener.
        max_results(int, optional): The number of endpoint group objects that you want to return with this call. The default value is 10. Defaults to None.
        next_token(str, optional): The token for the next set of results. You receive this token from a previous call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.endpoint_group.list_all(
                ctx, listener_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.endpoint_group.list_all listener_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="list_endpoint_groups",
        op_kwargs={
            "ListenerArn": listener_arn,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    endpoint_group_arn: str,
    endpoint_configurations: List = None,
    traffic_dial_percentage: float = None,
    health_check_port: int = None,
    health_check_protocol: str = None,
    health_check_path: str = None,
    health_check_interval_seconds: int = None,
    threshold_count: int = None,
    port_overrides: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Update an endpoint group. A resource must be valid and active when you add it as an endpoint.

    Args:
        endpoint_group_arn(str): The Amazon Resource Name (ARN) of the endpoint group.
        endpoint_configurations(List, optional): The list of endpoint objects. A resource must be valid and active when you add it as an endpoint. Defaults to None.
        traffic_dial_percentage(float, optional): The percentage of traffic to send to an AWS Region. Additional traffic is distributed to other endpoint groups for this listener.  Use this action to increase (dial up) or decrease (dial down) traffic to a specific Region. The percentage is applied to the traffic that would otherwise have been routed to the Region based on optimal routing. The default value is 100. Defaults to None.
        health_check_port(int, optional): The port that AWS Global Accelerator uses to check the health of endpoints that are part of this endpoint group. The default port is the listener port that this endpoint group is associated with. If the listener port is a list of ports, Global Accelerator uses the first port in the list. Defaults to None.
        health_check_protocol(str, optional): The protocol that AWS Global Accelerator uses to check the health of endpoints that are part of this endpoint group. The default value is TCP. Defaults to None.
        health_check_path(str, optional): If the protocol is HTTP/S, then this specifies the path that is the destination for health check targets. The default value is slash (/). Defaults to None.
        health_check_interval_seconds(int, optional): The time—10 seconds or 30 seconds—between each health check for an endpoint. The default value is 30. Defaults to None.
        threshold_count(int, optional): The number of consecutive health checks required to set the state of a healthy endpoint to unhealthy, or to set an unhealthy endpoint to healthy. The default value is 3. Defaults to None.
        port_overrides(List, optional): Override specific listener ports used to route traffic to endpoints that are part of this endpoint group. For example, you can create a port override in which the listener receives user traffic on ports 80 and 443, but your accelerator routes that traffic to ports 1080 and 1443, respectively, on the endpoints. For more information, see  Port overrides in the AWS Global Accelerator Developer Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.endpoint_group.update(
                ctx, endpoint_group_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.endpoint_group.update endpoint_group_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="update_endpoint_group",
        op_kwargs={
            "EndpointGroupArn": endpoint_group_arn,
            "EndpointConfigurations": endpoint_configurations,
            "TrafficDialPercentage": traffic_dial_percentage,
            "HealthCheckPort": health_check_port,
            "HealthCheckProtocol": health_check_protocol,
            "HealthCheckPath": health_check_path,
            "HealthCheckIntervalSeconds": health_check_interval_seconds,
            "ThresholdCount": threshold_count,
            "PortOverrides": port_overrides,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    cluster_name: str,
    addon_name: str,
    addon_version: str = None,
    service_account_role_arn: str = None,
    resolve_conflicts: str = None,
    client_request_token: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Amazon EKS add-on. Amazon EKS add-ons help to automate the provisioning and lifecycle management of common operational software for Amazon EKS clusters. Amazon EKS add-ons can only be used with Amazon EKS clusters running version 1.18 with platform version eks.3 or later because add-ons rely on the Server-side Apply Kubernetes feature, which is only available in Kubernetes 1.18 and later.

    Args:
        cluster_name(str): The name of the cluster to create the add-on for.
        addon_name(str): The name of the add-on. The name must match one of the names returned by  DescribeAddonVersions .
        addon_version(str, optional): The version of the add-on. The version must match one of the versions returned by  DescribeAddonVersions . Defaults to None.
        service_account_role_arn(str, optional): The Amazon Resource Name (ARN) of an existing IAM role to bind to the add-on's service account. The role must be assigned the IAM permissions required by the add-on. If you don't specify an existing IAM role, then the add-on uses the permissions assigned to the node IAM role. For more information, see Amazon EKS node IAM role in the Amazon EKS User Guide.  To specify an existing IAM role, you must have an IAM OpenID Connect (OIDC) provider created for your cluster. For more information, see Enabling IAM roles for service accounts on your cluster in the Amazon EKS User Guide. . Defaults to None.
        resolve_conflicts(str, optional): How to resolve parameter value conflicts when migrating an existing add-on to an Amazon EKS add-on. Defaults to None.
        client_request_token(str, optional): A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.
        tags(Dict, optional): The metadata to apply to the cluster to assist with categorization and organization. Each tag consists of a key and an optional value, both of which you define. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.eks.addon.init.create(ctx, cluster_name=value, addon_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.eks.addon.init.create cluster_name=value, addon_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="eks",
        operation="create_addon",
        op_kwargs={
            "clusterName": cluster_name,
            "addonName": addon_name,
            "addonVersion": addon_version,
            "serviceAccountRoleArn": service_account_role_arn,
            "resolveConflicts": resolve_conflicts,
            "clientRequestToken": client_request_token,
            "tags": tags,
        },
    )


async def delete(hub, ctx, cluster_name: str, addon_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Delete an Amazon EKS add-on. When you remove the add-on, it will also be deleted from the cluster. You can always manually start an add-on on the cluster using the Kubernetes API.

    Args:
        cluster_name(str): The name of the cluster to delete the add-on from.
        addon_name(str): The name of the add-on. The name must match one of the names returned by  ListAddons .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.eks.addon.init.delete(ctx, cluster_name=value, addon_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.eks.addon.init.delete cluster_name=value, addon_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="eks",
        operation="delete_addon",
        op_kwargs={"clusterName": cluster_name, "addonName": addon_name},
    )


async def describe(hub, ctx, cluster_name: str, addon_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes an Amazon EKS add-on.

    Args:
        cluster_name(str): The name of the cluster.
        addon_name(str): The name of the add-on. The name must match one of the names returned by  ListAddons .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.eks.addon.init.describe(
                ctx, cluster_name=value, addon_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.eks.addon.init.describe cluster_name=value, addon_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="eks",
        operation="describe_addon",
        op_kwargs={"clusterName": cluster_name, "addonName": addon_name},
    )


async def list_all(
    hub, ctx, cluster_name: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the available add-ons.

    Args:
        cluster_name(str): The name of the cluster.
        max_results(int, optional): The maximum number of add-on results returned by ListAddonsRequest in paginated output. When you use this parameter, ListAddonsRequest returns only maxResults results in a single page along with a nextToken response element. You can see the remaining results of the initial request by sending another ListAddonsRequest request with the returned nextToken value. This value can be between 1 and 100. If you don't use this parameter, ListAddonsRequest returns up to 100 results and a nextToken value, if applicable. Defaults to None.
        next_token(str, optional): The nextToken value returned from a previous paginated ListAddonsRequest where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value.  This token should be treated as an opaque identifier that is used only to retrieve the next items in a list and not for other programmatic purposes. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.eks.addon.init.list_all(ctx, cluster_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.eks.addon.init.list_all cluster_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="eks",
        operation="list_addons",
        op_kwargs={
            "clusterName": cluster_name,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    cluster_name: str,
    addon_name: str,
    addon_version: str = None,
    service_account_role_arn: str = None,
    resolve_conflicts: str = None,
    client_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an Amazon EKS add-on.

    Args:
        cluster_name(str): The name of the cluster.
        addon_name(str): The name of the add-on. The name must match one of the names returned by  ListAddons .
        addon_version(str, optional): The version of the add-on. The version must match one of the versions returned by  DescribeAddonVersions . Defaults to None.
        service_account_role_arn(str, optional): The Amazon Resource Name (ARN) of an existing IAM role to bind to the add-on's service account. The role must be assigned the IAM permissions required by the add-on. If you don't specify an existing IAM role, then the add-on uses the permissions assigned to the node IAM role. For more information, see Amazon EKS node IAM role in the Amazon EKS User Guide.  To specify an existing IAM role, you must have an IAM OpenID Connect (OIDC) provider created for your cluster. For more information, see Enabling IAM roles for service accounts on your cluster in the Amazon EKS User Guide. . Defaults to None.
        resolve_conflicts(str, optional): How to resolve parameter value conflicts when applying the new version of the add-on to the cluster. Defaults to None.
        client_request_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.eks.addon.init.update(ctx, cluster_name=value, addon_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.eks.addon.init.update cluster_name=value, addon_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="eks",
        operation="update_addon",
        op_kwargs={
            "clusterName": cluster_name,
            "addonName": addon_name,
            "addonVersion": addon_version,
            "serviceAccountRoleArn": service_account_role_arn,
            "resolveConflicts": resolve_conflicts,
            "clientRequestToken": client_request_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def add(hub, ctx, pipeline_id: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds or modifies tags for the specified pipeline.

    Args:
        pipeline_id(str): The ID of the pipeline.
        tags(List): The tags to add, as key/value pairs.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datapipeline.tags.add(ctx, pipeline_id=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datapipeline.tags.add pipeline_id=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datapipeline",
        operation="add_tags",
        op_kwargs={"pipelineId": pipeline_id, "tags": tags},
    )


async def remove(hub, ctx, pipeline_id: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes existing tags from the specified pipeline.

    Args:
        pipeline_id(str): The ID of the pipeline.
        tag_keys(List): The keys of the tags to remove.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datapipeline.tags.remove(ctx, pipeline_id=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datapipeline.tags.remove pipeline_id=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datapipeline",
        operation="remove_tags",
        op_kwargs={"pipelineId": pipeline_id, "tagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, meeting_id: str, attendees: List) -> Dict:
    r"""
    **Autogenerated function**

     Creates up to 100 new attendees for an active Amazon Chime SDK meeting. For more information about the Amazon Chime SDK, see Using the Amazon Chime SDK in the Amazon Chime Developer Guide.

    Args:
        meeting_id(str): The Amazon Chime SDK meeting ID.
        attendees(List): The request containing the attendees to create.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.create.attendee.batch(
                ctx, meeting_id=value, attendees=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.create.attendee.batch meeting_id=value, attendees=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="batch_create_attendee",
        op_kwargs={"MeetingId": meeting_id, "Attendees": attendees},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def enable(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Enables all features in an organization. This enables the use of organization policies that can restrict the services and actions that can be called in each account. Until you enable all features, you have access only to consolidated billing, and you can't use any of the advanced account administration features that AWS Organizations supports. For more information, see Enabling All Features in Your Organization in the AWS Organizations User Guide.   This operation is required only for organizations that were created explicitly with only the consolidated billing features enabled. Calling this operation sends a handshake to every invited account in the organization. The feature set change can be finalized and the additional features enabled only after all administrators in the invited accounts approve the change by accepting the handshake.  After you enable all features, you can separately enable or disable individual policy types in a root using EnablePolicyType and DisablePolicyType. To see the status of policy types in a root, use ListRoots. After all invited member accounts accept the handshake, you finalize the feature set change by accepting the handshake that contains "Action": "ENABLE_ALL_FEATURES". This completes the change. After you enable all features in your organization, the management account in the organization can apply policies on all member accounts. These policies can restrict what users and even administrators in those accounts can do. The management account can apply policies that prevent accounts from leaving the organization. Ensure that your account administrators are aware of this. This operation can be called only from the organization's management account.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.all_feature.enable(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.all_feature.enable
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="organizations", operation="enable_all_features", op_kwargs={}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def cancel(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    The CancelJob operation cancels an unfinished job.  You can only cancel a job that has a status of Submitted. To prevent a pipeline from starting to process a job while you're getting the job identifier, use UpdatePipelineStatus to temporarily pause the pipeline.

    Args:
        id_(str): The identifier of the job that you want to cancel. To get a list of the jobs (including their jobId) that have a status of Submitted, use the ListJobsByStatus API action.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elastictranscoder.job.cancel(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elastictranscoder.job.cancel id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elastictranscoder",
        operation="cancel_job",
        op_kwargs={"Id": id_},
    )


async def create(
    hub,
    ctx,
    pipeline_id: str,
    input_: Dict = None,
    inputs: List = None,
    output: Dict = None,
    outputs: List = None,
    output_key_prefix: str = None,
    playlists: List = None,
    user_metadata: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    When you create a job, Elastic Transcoder returns JSON data that includes the values that you specified plus information about the job that is created. If you have specified more than one output for your jobs (for example, one output for the Kindle Fire and another output for the Apple iPhone 4s), you currently must use the Elastic Transcoder API to list the jobs (as opposed to the AWS Console).

    Args:
        pipeline_id(str): The Id of the pipeline that you want Elastic Transcoder to use for transcoding. The pipeline determines several settings, including the Amazon S3 bucket from which Elastic Transcoder gets the files to transcode and the bucket into which Elastic Transcoder puts the transcoded files.
        input_(Dict, optional): A section of the request body that provides information about the file that is being transcoded. Defaults to None.
        inputs(List, optional): A section of the request body that provides information about the files that are being transcoded. Defaults to None.
        output(Dict, optional):  A section of the request body that provides information about the transcoded (target) file. We strongly recommend that you use the Outputs syntax instead of the Output syntax. . Defaults to None.
        outputs(List, optional):  A section of the request body that provides information about the transcoded (target) files. We recommend that you use the Outputs syntax instead of the Output syntax. . Defaults to None.
        output_key_prefix(str, optional): The value, if any, that you want Elastic Transcoder to prepend to the names of all files that this job creates, including output files, thumbnails, and playlists. Defaults to None.
        playlists(List, optional): If you specify a preset in PresetId for which the value of Container is fmp4 (Fragmented MP4) or ts (MPEG-TS), Playlists contains information about the master playlists that you want Elastic Transcoder to create. The maximum number of master playlists in a job is 30. Defaults to None.
        user_metadata(Dict, optional): User-defined metadata that you want to associate with an Elastic Transcoder job. You specify metadata in key/value pairs, and you can add up to 10 key/value pairs per job. Elastic Transcoder does not guarantee that key/value pairs are returned in the same order in which you specify them. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elastictranscoder.job.create(ctx, pipeline_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elastictranscoder.job.create pipeline_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elastictranscoder",
        operation="create_job",
        op_kwargs={
            "PipelineId": pipeline_id,
            "Input": input_,
            "Inputs": inputs,
            "Output": output,
            "Outputs": outputs,
            "OutputKeyPrefix": output_key_prefix,
            "Playlists": playlists,
            "UserMetadata": user_metadata,
        },
    )


async def read(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    The ReadJob operation returns detailed information about a job.

    Args:
        id_(str): The identifier of the job for which you want to get detailed information.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elastictranscoder.job.read(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elastictranscoder.job.read id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elastictranscoder",
        operation="read_job",
        op_kwargs={"Id": id_},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    api_id: str,
    function_id: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    List the resolvers that are associated with a specific function.

    Args:
        api_id(str): The API ID.
        function_id(str): The Function ID.
        next_token(str, optional): An identifier that was returned from the previous call to this operation, which you can use to return the next set of items in the list. Defaults to None.
        max_results(int, optional): The maximum number of results you want the request to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.resolver.by_function.list(
                ctx, api_id=value, function_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.resolver.by_function.list api_id=value, function_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="list_resolvers_by_function",
        op_kwargs={
            "apiId": api_id,
            "functionId": function_id,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub,
    ctx,
    config_rule_name: str,
    compliance_types: List = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the evaluation results for the specified AWS Config rule. The results indicate which AWS resources were evaluated by the rule, when each resource was last evaluated, and whether each resource complies with the rule.

    Args:
        config_rule_name(str): The name of the AWS Config rule for which you want compliance information.
        compliance_types(List, optional): Filters the results by compliance. The allowed values are COMPLIANT, NON_COMPLIANT, and NOT_APPLICABLE. Defaults to None.
        limit(int, optional): The maximum number of evaluation results returned on each page. The default is 10. You cannot specify a number greater than 100. If you specify 0, AWS Config uses the default. Defaults to None.
        next_token(str, optional): The nextToken string returned on a previous page that you use to get the next page of results in a paginated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.compliance.detail_by.config_rule.get(
                ctx, config_rule_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.compliance.detail_by.config_rule.get config_rule_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="get_compliance_details_by_config_rule",
        op_kwargs={
            "ConfigRuleName": config_rule_name,
            "ComplianceTypes": compliance_types,
            "Limit": limit,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    vocabulary_name: str,
    language_code: str,
    phrases: List = None,
    vocabulary_file_uri: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new custom vocabulary that you can use to change the way Amazon Transcribe handles transcription of an audio file.

    Args:
        vocabulary_name(str): The name of the vocabulary. The name must be unique within an AWS account. The name is case sensitive. If you try to create a vocabulary with the same name as a previous vocabulary you will receive a ConflictException error.
        language_code(str): The language code of the vocabulary entries. For a list of languages and their corresponding language codes, see what-is-transcribe.
        phrases(List, optional): An array of strings that contains the vocabulary entries. . Defaults to None.
        vocabulary_file_uri(str, optional): The S3 location of the text file that contains the definition of the custom vocabulary. The URI must be in the same region as the API endpoint that you are calling. The general form is  For more information about S3 object names, see Object Keys in the Amazon S3 Developer Guide. For more information about custom vocabularies, see Custom Vocabularies. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transcribe.vocabulary.init.create(
                ctx, vocabulary_name=value, language_code=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transcribe.vocabulary.init.create vocabulary_name=value, language_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transcribe",
        operation="create_vocabulary",
        op_kwargs={
            "VocabularyName": vocabulary_name,
            "LanguageCode": language_code,
            "Phrases": phrases,
            "VocabularyFileUri": vocabulary_file_uri,
        },
    )


async def delete(hub, ctx, vocabulary_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a vocabulary from Amazon Transcribe.

    Args:
        vocabulary_name(str): The name of the vocabulary to delete. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transcribe.vocabulary.init.delete(ctx, vocabulary_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transcribe.vocabulary.init.delete vocabulary_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transcribe",
        operation="delete_vocabulary",
        op_kwargs={"VocabularyName": vocabulary_name},
    )


async def get(hub, ctx, vocabulary_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a vocabulary.

    Args:
        vocabulary_name(str): The name of the vocabulary to return information about. The name is case sensitive.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transcribe.vocabulary.init.get(ctx, vocabulary_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transcribe.vocabulary.init.get vocabulary_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transcribe",
        operation="get_vocabulary",
        op_kwargs={"VocabularyName": vocabulary_name},
    )


async def list_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    state_equals: str = None,
    name_contains: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of vocabularies that match the specified criteria. If no criteria are specified, returns the entire list of vocabularies.

    Args:
        next_token(str, optional): If the result of the previous request to ListVocabularies was truncated, include the NextToken to fetch the next set of jobs. Defaults to None.
        max_results(int, optional): The maximum number of vocabularies to return in the response. If there are fewer results in the list, this response contains only the actual results. Defaults to None.
        state_equals(str, optional): When specified, only returns vocabularies with the VocabularyState field equal to the specified state. Defaults to None.
        name_contains(str, optional): When specified, the vocabularies returned in the list are limited to vocabularies whose name contains the specified string. The search is not case sensitive, ListVocabularies returns both "vocabularyname" and "VocabularyName" in the response list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transcribe.vocabulary.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transcribe.vocabulary.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transcribe",
        operation="list_vocabularies",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "StateEquals": state_equals,
            "NameContains": name_contains,
        },
    )


async def update(
    hub,
    ctx,
    vocabulary_name: str,
    language_code: str,
    phrases: List = None,
    vocabulary_file_uri: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing vocabulary with new values. The UpdateVocabulary operation overwrites all of the existing information with the values that you provide in the request.

    Args:
        vocabulary_name(str): The name of the vocabulary to update. The name is case sensitive. If you try to update a vocabulary with the same name as a previous vocabulary you will receive a ConflictException error.
        language_code(str): The language code of the vocabulary entries. For a list of languages and their corresponding language codes, see what-is-transcribe.
        phrases(List, optional): An array of strings containing the vocabulary entries. Defaults to None.
        vocabulary_file_uri(str, optional): The S3 location of the text file that contains the definition of the custom vocabulary. The URI must be in the same region as the API endpoint that you are calling. The general form is  For example: For more information about S3 object names, see Object Keys in the Amazon S3 Developer Guide. For more information about custom vocabularies, see Custom Vocabularies. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transcribe.vocabulary.init.update(
                ctx, vocabulary_name=value, language_code=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transcribe.vocabulary.init.update vocabulary_name=value, language_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transcribe",
        operation="update_vocabulary",
        op_kwargs={
            "VocabularyName": vocabulary_name,
            "LanguageCode": language_code,
            "Phrases": phrases,
            "VocabularyFileUri": vocabulary_file_uri,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves an authorization token. An authorization token represents your IAM authentication credentials and can be used to access any Amazon ECR registry that your IAM principal has access to. The authorization token is valid for 12 hours. This API requires the ecr-public:GetAuthorizationToken and sts:GetServiceBearerToken permissions.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr_public.authorization_token.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr_public.authorization_token.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr-public",
        operation="get_authorization_token",
        op_kwargs={},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, bucket: str, expected_bucket_owner: str = None) -> None:
    r"""
    **Autogenerated function**

    This action removes the website configuration for a bucket. Amazon S3 returns a 200 OK response upon successfully deleting a website configuration on the specified bucket. You will get a 200 OK response if the website configuration you are trying to delete does not exist on the bucket. Amazon S3 returns a 404 response if the bucket specified in the request does not exist. This DELETE action requires the S3:DeleteBucketWebsite permission. By default, only the bucket owner can delete the website configuration attached to a bucket. However, bucket owners can grant other users permission to delete the website configuration by writing a bucket policy granting them the S3:DeleteBucketWebsite permission.  For more information about hosting websites, see Hosting Websites on Amazon S3.  The following operations are related to DeleteBucketWebsite:    GetBucketWebsite     PutBucketWebsite

    Args:
        bucket(str): The bucket name for which you want to remove the website configuration. .
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.website.delete(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.website.delete bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="delete_bucket_website",
        op_kwargs={"Bucket": bucket, "ExpectedBucketOwner": expected_bucket_owner},
    )


async def get(hub, ctx, bucket: str, expected_bucket_owner: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the website configuration for a bucket. To host website on Amazon S3, you can configure a bucket as website by adding a website configuration. For more information about hosting websites, see Hosting Websites on Amazon S3.  This GET action requires the S3:GetBucketWebsite permission. By default, only the bucket owner can read the bucket website configuration. However, bucket owners can allow other users to read the website configuration by writing a bucket policy granting them the S3:GetBucketWebsite permission. The following operations are related to DeleteBucketWebsite:    DeleteBucketWebsite     PutBucketWebsite

    Args:
        bucket(str): The bucket name for which to get the website configuration.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.website.get(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.website.get bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="get_bucket_website",
        op_kwargs={"Bucket": bucket, "ExpectedBucketOwner": expected_bucket_owner},
    )


async def put(
    hub,
    ctx,
    bucket: str,
    website_configuration: Dict,
    content_md5: str = None,
    expected_bucket_owner: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Sets the configuration of the website that is specified in the website subresource. To configure a bucket as a website, you can add this subresource on the bucket with website configuration information such as the file name of the index document and any redirect rules. For more information, see Hosting Websites on Amazon S3. This PUT action requires the S3:PutBucketWebsite permission. By default, only the bucket owner can configure the website attached to a bucket; however, bucket owners can allow other users to set the website configuration by writing a bucket policy that grants them the S3:PutBucketWebsite permission. To redirect all website requests sent to the bucket's website endpoint, you add a website configuration with the following elements. Because all requests are sent to another website, you don't need to provide index document name for the bucket.    WebsiteConfiguration     RedirectAllRequestsTo     HostName     Protocol    If you want granular control over redirects, you can use the following elements to add routing rules that describe conditions for redirecting requests and information about the redirect destination. In this case, the website configuration must provide an index document for the bucket, because some requests might not be redirected.     WebsiteConfiguration     IndexDocument     Suffix     ErrorDocument     Key     RoutingRules     RoutingRule     Condition     HttpErrorCodeReturnedEquals     KeyPrefixEquals     Redirect     Protocol     HostName     ReplaceKeyPrefixWith     ReplaceKeyWith     HttpRedirectCode    Amazon S3 has a limitation of 50 routing rules per website configuration. If you require more than 50 routing rules, you can use object redirect. For more information, see Configuring an Object Redirect in the Amazon S3 User Guide.

    Args:
        bucket(str): The bucket name.
        content_md5(str, optional): The base64-encoded 128-bit MD5 digest of the data. You must use this header as a message integrity check to verify that the request body was not corrupted in transit. For more information, see RFC 1864. For requests made using the AWS Command Line Interface (CLI) or AWS SDKs, this field is calculated automatically. Defaults to None.
        website_configuration(Dict): Container for the request.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.website.put(
                ctx, bucket=value, website_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.website.put bucket=value, website_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="put_bucket_website",
        op_kwargs={
            "Bucket": bucket,
            "ContentMD5": content_md5,
            "WebsiteConfiguration": website_configuration,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    action_type: str,
    cluster_identifier: str = None,
    snapshot_identifier: str = None,
    owner_account: str = None,
    filters: List = None,
    marker: str = None,
    max_records: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns properties of possible node configurations such as node type, number of nodes, and disk usage for the specified action type.

    Args:
        action_type(str): The action type to evaluate for possible node configurations. Specify "restore-cluster" to get configuration combinations based on an existing snapshot. Specify "recommend-node-config" to get configuration recommendations based on an existing cluster or snapshot. Specify "resize-cluster" to get configuration combinations for elastic resize based on an existing cluster. .
        cluster_identifier(str, optional): The identifier of the cluster to evaluate for possible node configurations. Defaults to None.
        snapshot_identifier(str, optional): The identifier of the snapshot to evaluate for possible node configurations. Defaults to None.
        owner_account(str, optional): The Amazon Web Services account used to create or copy the snapshot. Required if you are restoring a snapshot you do not own, optional if you own the snapshot. Defaults to None.
        filters(List, optional): A set of name, operator, and value items to filter the results. Defaults to None.
        marker(str, optional): An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeNodeConfigurationOptions request exceed the value specified in MaxRecords, Amazon Web Services returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request. . Defaults to None.
        max_records(int, optional): The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value.  Default: 500  Constraints: minimum 100, maximum 500. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.node_configuration_option.describe_all(
                ctx, action_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.node_configuration_option.describe_all action_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_node_configuration_options",
        op_kwargs={
            "ActionType": action_type,
            "ClusterIdentifier": cluster_identifier,
            "SnapshotIdentifier": snapshot_identifier,
            "OwnerAccount": owner_account,
            "Filters": filters,
            "Marker": marker,
            "MaxRecords": max_records,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete_multiple(hub, ctx, name: str, shared_account_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes permissions for the specified private image. After you delete permissions for an image, AWS accounts to which you previously granted these permissions can no longer use the image.

    Args:
        name(str): The name of the private image.
        shared_account_id(str): The 12-digit identifier of the AWS account for which to delete image permissions.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.image.permission.delete_multiple(
                ctx, name=value, shared_account_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.image.permission.delete_multiple name=value, shared_account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="delete_image_permissions",
        op_kwargs={"Name": name, "SharedAccountId": shared_account_id},
    )


async def describe_all(
    hub,
    ctx,
    name: str,
    max_results: int = None,
    shared_aws_account_ids: List = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list that describes the permissions for shared AWS account IDs on a private image that you own.

    Args:
        name(str): The name of the private image for which to describe permissions. The image must be one that you own. .
        max_results(int, optional): The maximum size of each page of results. Defaults to None.
        shared_aws_account_ids(List, optional): The 12-digit identifier of one or more AWS accounts with which the image is shared. Defaults to None.
        next_token(str, optional): The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.image.permission.describe_all(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.image.permission.describe_all name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="describe_image_permissions",
        op_kwargs={
            "Name": name,
            "MaxResults": max_results,
            "SharedAwsAccountIds": shared_aws_account_ids,
            "NextToken": next_token,
        },
    )


async def update_multiple(
    hub, ctx, name: str, shared_account_id: str, image_permissions: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Adds or updates permissions for the specified private image.

    Args:
        name(str): The name of the private image.
        shared_account_id(str): The 12-digit identifier of the AWS account for which you want add or update image permissions.
        image_permissions(Dict): The permissions for the image.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.image.permission.update_multiple(
                ctx, name=value, shared_account_id=value, image_permissions=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.image.permission.update_multiple name=value, shared_account_id=value, image_permissions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="update_image_permissions",
        op_kwargs={
            "Name": name,
            "SharedAccountId": shared_account_id,
            "ImagePermissions": image_permissions,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(
    hub,
    ctx,
    resource_arns: List,
    principal: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the policies for the specified resources that you own and have shared.

    Args:
        resource_arns(List): The Amazon Resource Names (ARN) of the resources.
        principal(str, optional): The principal. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ram.resource.policy.get_all(ctx, resource_arns=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ram.resource.policy.get_all resource_arns=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ram",
        operation="get_resource_policies",
        op_kwargs={
            "resourceArns": resource_arns,
            "principal": principal,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, access_key_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the account identifier for the specified access key ID. Access keys consist of two parts: an access key ID (for example, AKIAIOSFODNN7EXAMPLE) and a secret access key (for example, wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY). For more information about access keys, see Managing Access Keys for IAM Users in the IAM User Guide. When you pass an access key ID to this operation, it returns the ID of the Amazon Web Services account to which the keys belong. Access key IDs beginning with AKIA are long-term credentials for an IAM user or the Amazon Web Services account root user. Access key IDs beginning with ASIA are temporary credentials that are created using STS operations. If the account in the response belongs to you, you can sign in as the root user and review your root user access keys. Then, you can pull a credentials report to learn which IAM user owns the keys. To learn who requested the temporary credentials for an ASIA access key, view the STS events in your CloudTrail logs in the IAM User Guide. This operation does not indicate the state of the access key. The key might be active, inactive, or deleted. Active keys might not have permissions to perform an operation. Providing a deleted access key might return an error that the key doesn't exist.

    Args:
        access_key_id(str): The identifier of an access key. This parameter allows (through its regex pattern) a string of characters that can consist of any upper- or lowercase letter or digit.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sts.access_key_info.get(ctx, access_key_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sts.access_key_info.get access_key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sts",
        operation="get_access_key_info",
        op_kwargs={"AccessKeyId": access_key_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "change_set"


async def create(
    hub,
    ctx,
    application_id: str,
    stack_name: str,
    capabilities: List = None,
    change_set_name: str = None,
    client_token: str = None,
    description: str = None,
    notification_arns: List = None,
    parameter_overrides: List = None,
    resource_types: List = None,
    rollback_configuration: Dict = None,
    semantic_version: str = None,
    tags: List = None,
    template_id: str = None,
) -> Dict:
    r"""
        **Autogenerated function**

        Creates an AWS CloudFormation change set for the given application.

        Args:
            application_id(str): The Amazon Resource Name (ARN) of the application.
            capabilities(List, optional): A list of values that you must specify before you can deploy certain applications.
     Some applications might include resources that can affect permissions in your AWS
     account, for example, by creating new AWS Identity and Access Management (IAM) users.
     For those applications, you must explicitly acknowledge their capabilities by
     specifying this parameter.The only valid values are CAPABILITY_IAM, CAPABILITY_NAMED_IAM,
     CAPABILITY_RESOURCE_POLICY, and CAPABILITY_AUTO_EXPAND.The following resources require you to specify CAPABILITY_IAM or
     CAPABILITY_NAMED_IAM:
     AWS::IAM::Group,
     AWS::IAM::InstanceProfile,
     AWS::IAM::Policy, and
     AWS::IAM::Role.
     If the application contains IAM resources, you can specify either CAPABILITY_IAM
     or CAPABILITY_NAMED_IAM. If the application contains IAM resources
     with custom names, you must specify CAPABILITY_NAMED_IAM.The following resources require you to specify CAPABILITY_RESOURCE_POLICY:
     AWS::Lambda::Permission,
     AWS::IAM:Policy,
     AWS::ApplicationAutoScaling::ScalingPolicy,
     AWS::S3::BucketPolicy,
     AWS::SQS::QueuePolicy, and
     AWS::SNS:TopicPolicy.Applications that contain one or more nested applications require you to specify
     CAPABILITY_AUTO_EXPAND.If your application template contains any of the above resources, we recommend that you review
     all permissions associated with the application before deploying. If you don't specify
     this parameter for an application that requires capabilities, the call will fail. Defaults to None.
            change_set_name(str, optional): This property corresponds to the parameter of the same name for the AWS CloudFormation CreateChangeSet
     API. Defaults to None.
            client_token(str, optional): This property corresponds to the parameter of the same name for the AWS CloudFormation CreateChangeSet
     API. Defaults to None.
            description(str, optional): This property corresponds to the parameter of the same name for the AWS CloudFormation CreateChangeSet
     API. Defaults to None.
            notification_arns(List, optional): This property corresponds to the parameter of the same name for the AWS CloudFormation CreateChangeSet
     API. Defaults to None.
            parameter_overrides(List, optional): A list of parameter values for the parameters of the application. Defaults to None.
            resource_types(List, optional): This property corresponds to the parameter of the same name for the AWS CloudFormation CreateChangeSet
     API. Defaults to None.
            rollback_configuration(Dict, optional): This property corresponds to the parameter of the same name for the AWS CloudFormation CreateChangeSet
     API. Defaults to None.
            semantic_version(str, optional): The semantic version of the application:
    https://semver.org/
    . Defaults to None.
            stack_name(str): This property corresponds to the parameter of the same name for the AWS CloudFormation CreateChangeSet
     API.
            tags(List, optional): This property corresponds to the parameter of the same name for the AWS CloudFormation CreateChangeSet
     API. Defaults to None.
            template_id(str, optional): The UUID returned by CreateCloudFormationTemplate.Pattern: [0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}. Defaults to None.

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.serverlessrepo.cloud_formation.change_set_.create(
                    ctx, application_id=value, stack_name=value
                )

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.serverlessrepo.cloud_formation.change_set.create application_id=value, stack_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="serverlessrepo",
        operation="create_cloud_formation_change_set",
        op_kwargs={
            "ApplicationId": application_id,
            "Capabilities": capabilities,
            "ChangeSetName": change_set_name,
            "ClientToken": client_token,
            "Description": description,
            "NotificationArns": notification_arns,
            "ParameterOverrides": parameter_overrides,
            "ResourceTypes": resource_types,
            "RollbackConfiguration": rollback_configuration,
            "SemanticVersion": semantic_version,
            "StackName": stack_name,
            "Tags": tags,
            "TemplateId": template_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub,
    ctx,
    date_interval: Dict,
    monitor_arn: str = None,
    feedback: str = None,
    total_impact: Dict = None,
    next_page_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves all of the cost anomalies detected on your account, during the time period specified by the DateInterval object.

    Args:
        monitor_arn(str, optional): Retrieves all of the cost anomalies detected for a specific cost anomaly monitor Amazon Resource Name (ARN). . Defaults to None.
        date_interval(Dict): Assigns the start and end dates for retrieving cost anomalies. The returned anomaly object will have an AnomalyEndDate in the specified time range. .
        feedback(str, optional): Filters anomaly results by the feedback field on the anomaly object. . Defaults to None.
        total_impact(Dict, optional): Filters anomaly results by the total impact field on the anomaly object. For example, you can filter anomalies GREATER_THAN 200.00 to retrieve anomalies, with an estimated dollar impact greater than 200. . Defaults to None.
        next_page_token(str, optional):  The token to retrieve the next set of results. AWS provides the token when the response from a previous call has more results than the maximum page size. . Defaults to None.
        max_results(int, optional):  The number of entries a paginated response contains. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ce.anomaly.init.get_all(ctx, date_interval=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ce.anomaly.init.get_all date_interval=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ce",
        operation="get_anomalies",
        op_kwargs={
            "MonitorArn": monitor_arn,
            "DateInterval": date_interval,
            "Feedback": feedback,
            "TotalImpact": total_impact,
            "NextPageToken": next_page_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Provides the sending limits for the Amazon SES account.  You can execute this operation no more than once per second.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.send.quota.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.send.quota.get
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="ses", operation="get_send_quota", op_kwargs={}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, field_level_encryption_config: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Create a new field-level encryption configuration.

    Args:
        field_level_encryption_config(Dict): The request to create a new field-level encryption configuration.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.field_level_encryption.config.create(
                ctx, field_level_encryption_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.field_level_encryption.config.create field_level_encryption_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="create_field_level_encryption_config",
        op_kwargs={"FieldLevelEncryptionConfig": field_level_encryption_config},
    )


async def delete(hub, ctx, id_: str, if_match: str = None) -> None:
    r"""
    **Autogenerated function**

    Remove a field-level encryption configuration.

    Args:
        id_(str): The ID of the configuration you want to delete from CloudFront.
        if_match(str, optional): The value of the ETag header that you received when retrieving the configuration identity to delete. For example: E2QWRUHAPOMQZL. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.field_level_encryption.config.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.field_level_encryption.config.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="delete_field_level_encryption_config",
        op_kwargs={"Id": id_, "IfMatch": if_match},
    )


async def get(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Get the field-level encryption configuration information.

    Args:
        id_(str): Request the ID for the field-level encryption configuration information.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.field_level_encryption.config.get(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.field_level_encryption.config.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="get_field_level_encryption_config",
        op_kwargs={"Id": id_},
    )


async def list_all(hub, ctx, marker: str = None, max_items: str = None) -> Dict:
    r"""
    **Autogenerated function**

    List all field-level encryption configurations that have been created in CloudFront for this account.

    Args:
        marker(str, optional): Use this when paginating results to indicate where to begin in your list of configurations. The results include configurations in the list that occur after the marker. To get the next page of results, set the Marker to the value of the NextMarker from the current page's response (which is also the ID of the last configuration on that page). . Defaults to None.
        max_items(str, optional): The maximum number of field-level encryption configurations you want in the response body. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.field_level_encryption.config.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.field_level_encryption.config.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="list_field_level_encryption_configs",
        op_kwargs={"Marker": marker, "MaxItems": max_items},
    )


async def update(
    hub, ctx, field_level_encryption_config: Dict, id_: str, if_match: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Update a field-level encryption configuration.

    Args:
        field_level_encryption_config(Dict): Request to update a field-level encryption configuration. .
        id_(str): The ID of the configuration you want to update.
        if_match(str, optional): The value of the ETag header that you received when retrieving the configuration identity to update. For example: E2QWRUHAPOMQZL. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.field_level_encryption.config.update(
                ctx, field_level_encryption_config=value, id_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.field_level_encryption.config.update field_level_encryption_config=value, id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="update_field_level_encryption_config",
        op_kwargs={
            "FieldLevelEncryptionConfig": field_level_encryption_config,
            "Id": id_,
            "IfMatch": if_match,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "access_property"


async def modify(hub, ctx, resource_id: str, workspace_access_properties: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Specifies which devices and operating systems users can use to access their WorkSpaces. For more information, see  Control Device Access.

    Args:
        resource_id(str): The identifier of the directory.
        workspace_access_properties(Dict): The device types and operating systems to enable or disable for access.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.workspace.access_property_.modify(
                ctx, resource_id=value, workspace_access_properties=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.workspace.access_property.modify resource_id=value, workspace_access_properties=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="modify_workspace_access_properties",
        op_kwargs={
            "ResourceId": resource_id,
            "WorkspaceAccessProperties": workspace_access_properties,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "import"


async def delete(hub, ctx, import_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes a previous import and the associated file stored in an S3 bucket.

    Args:
        import_id(str): The unique identifier of the import to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.import_.delete(ctx, import_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.import.delete import_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="delete_import",
        op_kwargs={"importId": import_id},
    )


async def describe(hub, ctx, import_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a specific import.

    Args:
        import_id(str): The unique identifier of the import to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.import_.describe(ctx, import_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.import.describe import_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="describe_import",
        op_kwargs={"importId": import_id},
    )


async def list_all(
    hub,
    ctx,
    bot_id: str = None,
    bot_version: str = None,
    sort_by: Dict = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the imports for a bot or bot locale. Imports are kept in the list for 7 days.

    Args:
        bot_id(str, optional): The unique identifier that Amazon Lex assigned to the bot. Defaults to None.
        bot_version(str, optional): The version of the bot to list imports for. Defaults to None.
        sort_by(Dict, optional): Determines the field that the list of imports is sorted by. You can sort by the LastUpdatedDateTime field in ascending or descending order. Defaults to None.
        filters(List, optional): Provides the specification of a filter used to limit the bots in the response to only those that match the filter specification. You can only specify one filter and one string to filter on. Defaults to None.
        max_results(int, optional): The maximum number of imports to return in each page of results. If there are fewer results than the max page size, only the actual number of results are returned. Defaults to None.
        next_token(str, optional): If the response from the ListImports operation contains more results than specified in the maxResults parameter, a token is returned in the response. Use that token in the nextToken parameter to return the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.import_.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.import.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="list_imports",
        op_kwargs={
            "botId": bot_id,
            "botVersion": bot_version,
            "sortBy": sort_by,
            "filters": filters,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def start(
    hub,
    ctx,
    import_id: str,
    resource_specification: Dict,
    merge_strategy: str,
    file_password: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts importing a bot or bot locale from a zip archive that you uploaded to an S3 bucket.

    Args:
        import_id(str): The unique identifier for the import. It is included in the response from the operation.
        resource_specification(Dict): Parameters for creating the bot or bot locale.
        merge_strategy(str): The strategy to use when there is a name conflict between the imported resource and an existing resource. When the merge strategy is FailOnConflict existing resources are not overwritten and the import fails.
        file_password(str, optional): The password used to encrypt the zip archive that contains the bot or bot locale definition. You should always encrypt the zip archive to protect it during transit between your site and Amazon Lex. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.import_.start(
                ctx, import_id=value, resource_specification=value, merge_strategy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.import.start import_id=value, resource_specification=value, merge_strategy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="start_import",
        op_kwargs={
            "importId": import_id,
            "resourceSpecification": resource_specification,
            "mergeStrategy": merge_strategy,
            "filePassword": file_password,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    ec2_instance_type: str,
    description: str = None,
    build_id: str = None,
    script_id: str = None,
    server_launch_path: str = None,
    server_launch_parameters: str = None,
    log_paths: List = None,
    ec2_inbound_permissions: List = None,
    new_game_session_protection_policy: str = None,
    runtime_configuration: Dict = None,
    resource_creation_limit_policy: Dict = None,
    metric_groups: List = None,
    peer_vpc_aws_account_id: str = None,
    peer_vpc_id: str = None,
    fleet_type: str = None,
    instance_role_arn: str = None,
    certificate_configuration: Dict = None,
    locations: List = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a fleet of Amazon Elastic Compute Cloud (Amazon EC2) instances to host your custom game server or Realtime Servers. Use this operation to configure the computing resources for your fleet and provide instructions for running game servers on each instance. Most GameLift fleets can deploy instances to multiple locations, including the home Region (where the fleet is created) and an optional set of remote locations. Fleets that are created in the following AWS Regions support multiple locations: us-east-1 (N. Virginia), us-west-2 (Oregon), eu-central-1 (Frankfurt), eu-west-1 (Ireland), ap-southeast-2 (Sydney), ap-northeast-1 (Tokyo), and ap-northeast-2 (Seoul). Fleets that are created in other GameLift Regions can deploy instances in the fleet's home Region only. All fleet instances use the same configuration regardless of location; however, you can adjust capacity settings and turn auto-scaling on/off for each location. To create a fleet, choose the hardware for your instances, specify a game server build or Realtime script to deploy, and provide a runtime configuration to direct GameLift how to start and run game servers on each instance in the fleet. Set permissions for inbound traffic to your game servers, and enable optional features as needed. When creating a multi-location fleet, provide a list of additional remote locations. If successful, this operation creates a new Fleet resource and places it in NEW status, which prompts GameLift to initiate the fleet creation workflow. You can track fleet creation by checking fleet status using DescribeFleetAttributes and DescribeFleetLocationAttributes/, or by monitoring fleet creation events using DescribeFleetEvents. As soon as the fleet status changes to ACTIVE, you can enable automatic scaling for the fleet with PutScalingPolicy and set capacity for the home Region with UpdateFleetCapacity. When the status of each remote location reaches ACTIVE, you can set capacity by location using UpdateFleetCapacity.  Learn more   Setting up fleets   Debug fleet creation issues   Multi-location fleets   Related actions   CreateFleet | UpdateFleetCapacity | PutScalingPolicy | DescribeEC2InstanceLimits | DescribeFleetAttributes | DescribeFleetLocationAttributes | UpdateFleetAttributes | StopFleetActions | DeleteFleet | All APIs by task

    Args:
        name(str): A descriptive label that is associated with a fleet. Fleet names do not need to be unique.
        description(str, optional): A human-readable description of the fleet. Defaults to None.
        build_id(str, optional): The unique identifier for a custom game server build to be deployed on fleet instances. You can use either the build ID or ARN. The build must be uploaded to GameLift and in READY status. This fleet property cannot be changed later. Defaults to None.
        script_id(str, optional): The unique identifier for a Realtime configuration script to be deployed on fleet instances. You can use either the script ID or ARN. Scripts must be uploaded to GameLift prior to creating the fleet. This fleet property cannot be changed later. Defaults to None.
        server_launch_path(str, optional):  This parameter is no longer used. Specify a server launch path using the RuntimeConfiguration parameter. Requests that use this parameter instead continue to be valid. Defaults to None.
        server_launch_parameters(str, optional):  This parameter is no longer used. Specify server launch parameters using the RuntimeConfiguration parameter. Requests that use this parameter instead continue to be valid. Defaults to None.
        log_paths(List, optional):  This parameter is no longer used. To specify where GameLift should store log files once a server process shuts down, use the GameLift server API ProcessReady() and specify one or more directory paths in logParameters. See more information in the Server API Reference. . Defaults to None.
        ec2_instance_type(str): The GameLift-supported EC2 instance type to use for all fleet instances. Instance type determines the computing resources that will be used to host your game servers, including CPU, memory, storage, and networking capacity. See Amazon EC2 Instance Types for detailed descriptions of EC2 instance types.
        ec2_inbound_permissions(List, optional): The allowed IP address ranges and port settings that allow inbound traffic to access game sessions on this fleet. If the fleet is hosting a custom game build, this property must be set before players can connect to game sessions. For Realtime Servers fleets, GameLift automatically sets TCP and UDP ranges. . Defaults to None.
        new_game_session_protection_policy(str, optional): The status of termination protection for active game sessions on the fleet. By default, this property is set to NoProtection. You can also set game session protection for an individual game session by calling UpdateGameSession.    NoProtection - Game sessions can be terminated during active gameplay as a result of a scale-down event.     FullProtection - Game sessions in ACTIVE status cannot be terminated during a scale-down event.  . Defaults to None.
        runtime_configuration(Dict, optional): Instructions for how to launch and maintain server processes on instances in the fleet. The runtime configuration defines one or more server process configurations, each identifying a build executable or Realtime script file and the number of processes of that type to run concurrently.   The RuntimeConfiguration parameter is required unless the fleet is being configured using the older parameters ServerLaunchPath and ServerLaunchParameters, which are still supported for backward compatibility. . Defaults to None.
        resource_creation_limit_policy(Dict, optional): A policy that limits the number of game sessions that an individual player can create on instances in this fleet within a specified span of time. Defaults to None.
        metric_groups(List, optional): The name of an AWS CloudWatch metric group to add this fleet to. A metric group is used to aggregate the metrics for multiple fleets. You can specify an existing metric group name or set a new name to create a new metric group. A fleet can be included in only one metric group at a time. . Defaults to None.
        peer_vpc_aws_account_id(str, optional): Used when peering your GameLift fleet with a VPC, the unique identifier for the AWS account that owns the VPC. You can find your account ID in the AWS Management Console under account settings. . Defaults to None.
        peer_vpc_id(str, optional): A unique identifier for a VPC with resources to be accessed by your GameLift fleet. The VPC must be in the same Region as your fleet. To look up a VPC ID, use the VPC Dashboard in the AWS Management Console. Learn more about VPC peering in VPC Peering with GameLift Fleets. . Defaults to None.
        fleet_type(str, optional): Indicates whether to use On-Demand or Spot instances for this fleet. By default, this property is set to ON_DEMAND. Learn more about when to use  On-Demand versus Spot Instances. This property cannot be changed after the fleet is created. Defaults to None.
        instance_role_arn(str, optional): A unique identifier for an AWS IAM role that manages access to your AWS services. With an instance role ARN set, any application that runs on an instance in this fleet can assume the role, including install scripts, server processes, and daemons (background processes). Create a role or look up a role's ARN by using the IAM dashboard in the AWS Management Console. Learn more about using on-box credentials for your game servers at  Access external resources from a game server. This property cannot be changed after the fleet is created. Defaults to None.
        certificate_configuration(Dict, optional): Prompts GameLift to generate a TLS/SSL certificate for the fleet. TLS certificates are used for encrypting traffic between game clients and the game servers that are running on GameLift. By default, the CertificateConfiguration is set to DISABLED. Learn more at Securing Client/Server Communication. This property cannot be changed after the fleet is created.  Note: This feature requires the AWS Certificate Manager (ACM) service, which is not available in all AWS regions. When working in a region that does not support this feature, a fleet creation request with certificate generation fails with a 4xx error. Defaults to None.
        locations(List, optional): A set of remote locations to deploy additional instances to and manage as part of the fleet. This parameter can only be used when creating fleets in AWS Regions that support multiple locations. You can add any GameLift-supported AWS Region as a remote location, in the form of an AWS Region code such as us-west-2. To create a fleet with instances in the home Region only, omit this parameter. . Defaults to None.
        tags(List, optional): A list of labels to assign to the new fleet resource. Tags are developer-defined key-value pairs. Tagging AWS resources are useful for resource management, access management and cost allocation. For more information, see  Tagging AWS Resources in the AWS General Reference. Once the fleet is created, you can use TagResource, UntagResource, and ListTagsForResource to add, remove, and view tags. The maximum tag limit may be lower than stated. See the AWS General Reference for actual tagging limits. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.fleet.init.create(
                ctx, name=value, ec2_instance_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.fleet.init.create name=value, ec2_instance_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="create_fleet",
        op_kwargs={
            "Name": name,
            "Description": description,
            "BuildId": build_id,
            "ScriptId": script_id,
            "ServerLaunchPath": server_launch_path,
            "ServerLaunchParameters": server_launch_parameters,
            "LogPaths": log_paths,
            "EC2InstanceType": ec2_instance_type,
            "EC2InboundPermissions": ec2_inbound_permissions,
            "NewGameSessionProtectionPolicy": new_game_session_protection_policy,
            "RuntimeConfiguration": runtime_configuration,
            "ResourceCreationLimitPolicy": resource_creation_limit_policy,
            "MetricGroups": metric_groups,
            "PeerVpcAwsAccountId": peer_vpc_aws_account_id,
            "PeerVpcId": peer_vpc_id,
            "FleetType": fleet_type,
            "InstanceRoleArn": instance_role_arn,
            "CertificateConfiguration": certificate_configuration,
            "Locations": locations,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, fleet_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes all resources and information related a fleet. Any current fleet instances, including those in remote locations, are shut down. You don't need to call DeleteFleetLocations separately.  If the fleet being deleted has a VPC peering connection, you first need to get a valid authorization (good for 24 hours) by calling CreateVpcPeeringAuthorization. You do not need to explicitly delete the VPC peering connection--this is done as part of the delete fleet process.  To delete a fleet, specify the fleet ID to be terminated. During the deletion process the fleet status is changed to DELETING. When completed, the status switches to TERMINATED and the fleet event FLEET_DELETED is sent.  Learn more   Setting up GameLift Fleets   Related actions   CreateFleetLocations | UpdateFleetAttributes | UpdateFleetCapacity | UpdateFleetPortSettings | UpdateRuntimeConfiguration | StopFleetActions | StartFleetActions | PutScalingPolicy | DeleteFleet | DeleteFleetLocations | DeleteScalingPolicy | All APIs by task

    Args:
        fleet_id(str): A unique identifier for the fleet to be deleted. You can use either the fleet ID or ARN value.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.fleet.init.delete(ctx, fleet_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.fleet.init.delete fleet_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="delete_fleet",
        op_kwargs={"FleetId": fleet_id},
    )


async def list_all(
    hub,
    ctx,
    build_id: str = None,
    script_id: str = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a collection of fleet resources in an AWS Region. You can call this operation to get fleets in a previously selected default Region (see https://docs.aws.amazon.com/credref/latest/refdocs/setting-global-region.htmlor specify a Region in your request. You can filter the result set to find only those fleets that are deployed with a specific build or script. For fleets that have multiple locations, this operation retrieves fleets based on their home Region only. This operation can be used in the following ways:    To get a list of all fleets in a Region, don't provide a build or script identifier.    To get a list of all fleets where a specific custom game build is deployed, provide the build ID.   To get a list of all Realtime Servers fleets with a specific configuration script, provide the script ID.    Use the pagination parameters to retrieve results as a set of sequential pages.  If successful, a list of fleet IDs that match the request parameters is returned. A NextToken value is also returned if there are more result pages to retrieve.  Fleet resources are not listed in a particular order.   Learn more   Setting up GameLift fleets   Related actions   CreateFleet | UpdateFleetCapacity | PutScalingPolicy | DescribeEC2InstanceLimits | DescribeFleetAttributes | DescribeFleetLocationAttributes | UpdateFleetAttributes | StopFleetActions | DeleteFleet | All APIs by task

    Args:
        build_id(str, optional): A unique identifier for the build to request fleets for. Use this parameter to return only fleets using a specified build. Use either the build ID or ARN value. Defaults to None.
        script_id(str, optional): A unique identifier for the Realtime script to request fleets for. Use this parameter to return only fleets using a specified script. Use either the script ID or ARN value. Defaults to None.
        limit(int, optional): The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages. Defaults to None.
        next_token(str, optional): A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.fleet.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.fleet.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="list_fleets",
        op_kwargs={
            "BuildId": build_id,
            "ScriptId": script_id,
            "Limit": limit,
            "NextToken": next_token,
        },
    )
